import { loadAndProcessData } from './loadAndProcessData';

// Select the SVG element
const svg = d3.select('svg');

// Get the width and height of the SVG element
const width = +svg.attr('width');
const height = +svg.attr('height');

// Define the projection
const projection = d3.geoNaturalEarth1();

// Define the path generator
const pathGenerator = d3.geoPath().projection(projection);

// Append a 'g' element to the SVG for drawing elements
const g = svg.append('g');

// Append a 'path' element for the sphere (background)
g.append('path')
  .attr('class', 'sphere')
  .attr('d', pathGenerator({ type: 'Sphere' }));

// Enable zooming and panning functionality on the SVG
svg.call(d3.zoom().on('zoom', () => {
  g.attr('transform', d3.event.transform);
}));

// Create a color scale with a different color scheme (Blues)
const colorScale = d3.scaleOrdinal()
  .range(d3.schemeBlues[9]); // Adjust the range to the desired color scheme

// Define the value accessor function for color
const colorValue = d => d.properties.economy;

// Load and process the data
loadAndProcessData().then(countries => {
  // Set the domain for the color scale based on the data
  const tmp = colorScale.domain(countries.features.map(colorValue));
  console.log(colorScale.domain().sort());
  
  // Set the domain in sorted and reversed order and assign color range
  tmp.domain(colorScale.domain().sort().reverse())
    .range(d3.schemeBlues[colorScale.domain().length]); // Adjust the range to the desired color scheme
  
  // Append 'path' elements for each country and set fill color
  g.selectAll('path')
    .data(countries.features)
    .enter()
    .append('path')
    .attr('class', 'country')
    .attr('d', pathGenerator)
    .attr('fill', d => colorScale(colorValue(d)))
    .append('title')
    .text(d => d.properties.name + ': ' + colorValue(d));
});
