import { feature } from 'topojson';

export const loadAndProcessData = () =>
  Promise.all([
    d3.tsv('https://unpkg.com/world-atlas@1.1.4/world/110m.tsv'),
    d3.json('https://cdn.jsdelivr.net/npm/world-atlas@2/countries-110m.json')
  ]).then(([tsvData, topoJsonData]) => {
    // Parse TSV data and create a lookup object based on 'iso_n3' field
    const rowById = tsvData.reduce((accumulator, d) => {
      accumulator[d.iso_n3] = d;
      return accumulator;
    }, {});

    // Convert TopoJSON to GeoJSON using 'feature' function
    const countries = feature(topoJsonData, topoJsonData.objects.countries);

    // Assign TSV data to corresponding GeoJSON properties
    countries.features.forEach(d => {
      Object.assign(d.properties, rowById[d.id]);
    });

    return countries;
  });
